import { Component, Input, Output, EventEmitter, ViewChild, ViewEncapsulation, NgModule } from '@angular/core';
import { onProcessed, onDetected, init, start, stop, canvas, ImageDebug } from 'quagga';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

function mapToReader(value) {
    return [value + "_reader"];
}
var DEFAULT_CONFIG = {
    inputStream: {
        name: 'Live',
        type: 'LiveStream',
        target: null,
        constraints: {
            width: { min: 640 },
            height: { min: 480 },
            aspectRatio: { min: 1, max: 100 },
            facingMode: 'environment',
        },
        singleChannel: false
    },
    locator: {
        patchSize: 'medium',
        halfSample: true
    },
    locate: true,
    numOfWorkers: 4,
    decoder: {
        readers: ['code_128_reader']
    }
};
var BarecodeScannerLivestreamComponent = /** @class */ (function () {
    function BarecodeScannerLivestreamComponent() {
        this.valueChanges = new EventEmitter();
        this.started = false;
        this.configQuagga = DEFAULT_CONFIG;
    }
    BarecodeScannerLivestreamComponent.prototype.ngOnDestroy = function () {
        this.stop();
    };
    BarecodeScannerLivestreamComponent.prototype.ngOnChanges = function (changes) {
        this.retart();
    };
    BarecodeScannerLivestreamComponent.prototype._init = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            onProcessed(function (result) { return _this.onProcessed(result); });
            onDetected(function (result) { return _this.onDetected(result); });
            _this.configQuagga.inputStream.target = _this.BarecodeScanner.nativeElement;
            if (_this.type) {
                _this.configQuagga.decoder.readers = mapToReader(_this.type);
            }
            init(_this.configQuagga, function (err) {
                if (err) {
                    console.log(err);
                    return reject(err);
                }
                resolve();
            });
        });
    };
    BarecodeScannerLivestreamComponent.prototype.start = function () {
        var _this = this;
        if (!this.started) {
            this._init().then(function () {
                start();
                _this.started = true;
                console.log('started');
            });
        }
    };
    BarecodeScannerLivestreamComponent.prototype.stop = function () {
        if (this.started) {
            stop();
            this.started = false;
            console.log('stopped');
        }
    };
    BarecodeScannerLivestreamComponent.prototype.retart = function () {
        if (this.started) {
            this.stop();
            this.start();
        }
    };
    BarecodeScannerLivestreamComponent.prototype.isStarted = function () {
        return this.started;
    };
    BarecodeScannerLivestreamComponent.prototype.onProcessed = function (result) {
        var drawingCtx = canvas.ctx.overlay, drawingCanvas = canvas.dom.overlay;
        if (result) {
            if (result.boxes) {
                drawingCtx.clearRect(0, 0, parseInt(drawingCanvas.getAttribute('width')), parseInt(drawingCanvas.getAttribute('height')));
                result.boxes.filter(function (box) {
                    return box !== result.box;
                }).forEach(function (box) {
                    ImageDebug.drawPath(box, {
                        x: 0,
                        y: 1,
                    }, drawingCtx, {
                        color: 'green',
                        lineWidth: 2,
                    });
                });
            }
            if (result.box) {
                ImageDebug.drawPath(result.box, {
                    x: 0,
                    y: 1,
                }, drawingCtx, {
                    color: '#00F',
                    lineWidth: 2,
                });
            }
            if (result.codeResult && result.codeResult.code) {
                ImageDebug.drawPath(result.line, {
                    x: 'x',
                    y: 'y',
                }, drawingCtx, {
                    color: 'red',
                    lineWidth: 3,
                });
            }
        }
    };
    BarecodeScannerLivestreamComponent.prototype.onDetected = function (result) {
        var code = result.codeResult.code;
        this.valueChanges.next({ code: code });
    };
    return BarecodeScannerLivestreamComponent;
}());
BarecodeScannerLivestreamComponent.decorators = [
    { type: Component, args: [{
                selector: 'barcode-scanner-livestream',
                template: "<div #BarecodeScanner class=\"scanner\" [hidden]=\"!isStarted()\">\n</div>",
                styles: [".scanner{position:relative}.scanner canvas,.scanner video{max-width:100%;width:100%}.scanner canvas.drawingBuffer{position:absolute;left:0;top:0}"],
                encapsulation: ViewEncapsulation.None,
            },] },
];
BarecodeScannerLivestreamComponent.propDecorators = {
    type: [{ type: Input }],
    valueChanges: [{ type: Output }],
    BarecodeScanner: [{ type: ViewChild, args: ['BarecodeScanner',] }]
};
var BarecodeScannerLivestreamModule = /** @class */ (function () {
    function BarecodeScannerLivestreamModule() {
    }
    return BarecodeScannerLivestreamModule;
}());
BarecodeScannerLivestreamModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule
                ],
                declarations: [
                    BarecodeScannerLivestreamComponent
                ],
                exports: [
                    BarecodeScannerLivestreamComponent
                ]
            },] },
];
var BarecodeScannerLivestreamOverlayComponent = /** @class */ (function () {
    function BarecodeScannerLivestreamOverlayComponent() {
        this.valueChanges = new EventEmitter();
        this._showScanner = false;
    }
    Object.defineProperty(BarecodeScannerLivestreamOverlayComponent.prototype, "showScanner", {
        get: function () {
            return this._showScanner;
        },
        enumerable: true,
        configurable: true
    });
    BarecodeScannerLivestreamOverlayComponent.prototype.ngOnDestroy = function () {
        this.scanner.stop();
    };
    BarecodeScannerLivestreamOverlayComponent.prototype.show = function () {
        this._showScanner = true;
        this.scanner.start();
    };
    BarecodeScannerLivestreamOverlayComponent.prototype.hide = function () {
        this._showScanner = false;
        this.scanner.stop();
    };
    BarecodeScannerLivestreamOverlayComponent.prototype.onValueChanges = function (result) {
        this.valueChanges.next(result);
    };
    return BarecodeScannerLivestreamOverlayComponent;
}());
BarecodeScannerLivestreamOverlayComponent.decorators = [
    { type: Component, args: [{
                selector: 'barcode-scanner-livestream-overlay',
                template: "<div class=\"barcode-scanner-livestream-overlay\" [hidden]=\"!showScanner\">\n    <div class=\"barcode-scanner-livestream-overlay-content\">\n        <div class=\"barcode-scanner-livestream-overlay-close\" (click)=\"hide()\">X</div>\n        <barcode-scanner-livestream [type]=\"type\" (valueChanges)=\"onValueChanges($event)\"></barcode-scanner-livestream>\n    </div>\n</div>",
                styles: [".barcode-scanner-livestream-overlay{overflow:hidden;position:fixed;top:0;bottom:0;left:0;right:0;width:100%;background-color:rgba(0,0,0,.3);z-index:1000}.barcode-scanner-livestream-overlay .barcode-scanner-livestream-overlay-content{top:50%;position:absolute;left:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:90%;max-height:90%;max-width:800px}.barcode-scanner-livestream-overlay .barcode-scanner-livestream-overlay-content .barcode-scanner-livestream-overlay-close{position:absolute;right:0;padding:.5rem;width:2rem;height:2rem;line-height:2rem;text-align:center;background-color:#fff;cursor:pointer;border:3px solid #000;font-size:1.5rem;margin:-1rem;border-radius:2rem;z-index:100;-webkit-box-sizing:content-box;box-sizing:content-box}"],
            },] },
];
BarecodeScannerLivestreamOverlayComponent.propDecorators = {
    type: [{ type: Input }],
    valueChanges: [{ type: Output }],
    scanner: [{ type: ViewChild, args: [BarecodeScannerLivestreamComponent,] }]
};
var BarecodeScannerLivestreamOverlayModule = /** @class */ (function () {
    function BarecodeScannerLivestreamOverlayModule() {
    }
    return BarecodeScannerLivestreamOverlayModule;
}());
BarecodeScannerLivestreamOverlayModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    BarecodeScannerLivestreamModule
                ],
                declarations: [
                    BarecodeScannerLivestreamOverlayComponent
                ],
                exports: [
                    BarecodeScannerLivestreamOverlayComponent
                ]
            },] },
];

export { BarecodeScannerLivestreamModule, BarecodeScannerLivestreamComponent, BarecodeScannerLivestreamOverlayModule, BarecodeScannerLivestreamOverlayComponent };
//# sourceMappingURL=ngx-barcode-scanner.js.map
